@@ -13,18 +13,18 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/s390x-linux-gnu/python3.9',
  'BLDLIBRARY': '-lpython3.9',
- 'BLDSHARED': 's390x-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions  '
+ 'BLDSHARED': 's390x-linux-gnu-gcc -shared -Wl,-O1 -Wl,-Bsymbolic-functions '
+              '-Wl,-Bsymbolic-functions  '
               ' -Wl,-z,relro -g '
               '-fwrapv -O2   ',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 's390x-ibm-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 's390x-linux-gnu-gcc -pthread',
+ 'CC': 's390x-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall -g '
-           '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+           ' '
            '  '
            ' -fstack-protector-strong '
            '-Wformat -Werror=format-security  -g -fwrapv -O2  '
@@ -35,7 +35,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-g '
-                     '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+                     ' '
                      '  '
                      ' '
                      '-fstack-protector-strong -Wformat -Werror=format-security',
@@ -55,9 +55,9 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-libmpdec' '--with-system-ffi' "
-                "'CC=s390x-linux-gnu-gcc' 'CFLAGS=-g "
-                '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+                "'--with-system-libmpdec' 'MKDIR_P=/bin/mkdir -p' "
+                "'--with-system-ffi' 'CC=s390x-linux-gnu-gcc' 'CFLAGS=-g "
+                ' '
                 '  '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security ' "
@@ -68,13 +68,13 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
              '-D_FORTIFY_SOURCE=2',
- 'CXX': 's390x-linux-gnu-g++ -pthread',
+ 'CXX': 's390x-linux-gnu-g++',
  'DESTDIRS': '/usr /usr/lib/s390x-linux-gnu /usr/lib/s390x-linux-gnu/python3.9 '
              '/usr/lib/python3.9/lib-dynload',
  'DESTLIB': '/usr/lib/python3.9',
@@ -335,6 +335,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -549,16 +550,15 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 's390x-linux-gnu-g++ -pthread -shared -Wl,-O1 '
-                '-Wl,-Bsymbolic-functions',
+ 'LDCXXSHARED': 's390x-linux-gnu-g++ -shared -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LDFLAGS': '-Wl,-Bsymbolic-functions  '
             ' -Wl,-z,relro -g -fwrapv '
             '-O2   ',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 's390x-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-             '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions  '
+ 'LDSHARED': 's390x-linux-gnu-gcc -shared -Wl,-O1 -Wl,-Bsymbolic-functions '
+             '-Wl,-Bsymbolic-functions  '
              ' -Wl,-z,relro -g -fwrapv '
              '-O2   ',
  'LDVERSION': '3.9',
@@ -575,9 +575,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'LIBS': '-lcrypt -ldl  -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 's390x-linux-gnu-gcc -pthread',
+ 'LINKCC': 's390x-linux-gnu-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -591,12 +591,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/s390x-linux-gnu/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 's390x-linux-gnu-gcc -pthread',
+ 'MAINCC': 's390x-linux-gnu-gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  cmath  math  _struct  _random  _elementtree  '
                    '_pickle  _datetime  _bisect  _heapq  _statistics  '
                    'unicodedata  fcntl  spwd  grp  select  _csv  _socket  '
@@ -681,7 +681,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O2 -Wall -g '
-                             '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+                             ' '
                              '  '
                              ' '
                              '-fstack-protector-strong -Wformat '
@@ -695,7 +695,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-g -ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+              '-g  '
               '  '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security  -g -fwrapv -O2  '
@@ -707,7 +707,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 '
                    '-Wall -g '
-                   '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+                   ' '
                    '  '
                    ' '
                    '-fstack-protector-strong -Wformat -Werror=format-security  -g '
@@ -732,7 +732,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O2 -Wall -g '
-                        '-ffile-prefix-map=/build/python3.9-XgHEQC/python3.9-3.9.5=. '
+                        ' '
                         '  '
                         ' '
                         '-fstack-protector-strong -Wformat -Werror=format-security  '
@@ -751,14 +751,14 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -793,10 +793,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -820,8 +820,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared',
- 'abs_srcdir': '/build/python3.9-XgHEQC/python3.9-3.9.5/build-shared/..',
+ 'abs_builddir': '/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared',
+ 'abs_srcdir': '/build/python3.9-mlaWKQ/python3.9-3.9.7/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
